@@ -1,20 +1,8 @@
 /*
  * This file is part of KMail.
- * Copyright (c) 2009 Constantin Berzan <exit3219@gmail.com>
+ * SPDX-FileCopyrightText: 2009 Constantin Berzan <exit3219@gmail.com>
  *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License along
- * with this program; if not, write to the Free Software Foundation, Inc.,
- * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
+ * SPDX-License-Identifier: GPL-2.0-or-later
  */
 #ifndef AKONADISENDER_H
 #define AKONADISENDER_H
@@ -30,6 +18,9 @@ class KJob;
 
 namespace MessageComposer {
 class AkonadiSenderPrivate;
+/**
+ * @brief The AkonadiSender class
+ */
 class MESSAGECOMPOSER_EXPORT AkonadiSender : public QObject, public MessageSender
 {
     Q_OBJECT
@@ -50,13 +41,13 @@ protected:
 
     TODO cberzan: update docu...
     */
-    bool doSend(const KMime::Message::Ptr &msg, short sendNow) override;
+    Q_REQUIRED_RESULT bool doSend(const KMime::Message::Ptr &msg, short sendNow) override;
 
     /**
     Send queued messages, using the specified transport or the
     default, if none is given.
     */
-    bool doSendQueued(int transportId = -1) override;
+    Q_REQUIRED_RESULT bool doSendQueued(int transportId = -1) override;
 
 private:
     /**
